#
# spec file for package netlabel
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           netlabel
%define         netlabel_docdir %{_docdir}/%{name}
Version:        0.21
Release:        3.7
Summary:        Explicit labeled networking for Linux
License:        GPL-2.0-only
Group:          Productivity/Networking/Security
URL:            https://github.com/netlabel/netlabel_tools/wiki
Source0:        https://github.com/netlabel/netlabel_tools/releases/download/v%{version}/netlabel_tools-%{version}.tar.gz
BuildRequires:  doxygen
BuildRequires:  pkg-config
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(libnl-3.0)
# PATCH-FIX-OPENSUSE netlabel_tools-0.20-service.diff mt@suse.de
Patch1:         netlabel_tools-0.20-service.diff
Patch2:         harden_netlabel.service.patch

%description
Explicit labeled networking for Linux

The NetLabel control utility, netlabelctl, is a command line program designed
to allow system administrators to configure the NetLabel system in the kernel.
The utility is based around different "modules" which correspond to the
different types of NetLabel commands supported by the kernel.

%package tools
Summary:        Control utility for explicit labeled networking for Linux
Group:          Productivity/Networking/Security

%description tools
Explicit labeled networking for Linux

The NetLabel control utility, netlabelctl, is a command line program designed
to allow system administrators to configure the NetLabel system in the kernel.
The utility is based around different "modules" which correspond to the
different types of NetLabel commands supported by the kernel.

#
# Note: there's no NetLabel Daemon implemented yet,
#       the libraries are not installed by default.
#
%prep
%setup -q -n netlabel_tools-%{version}
%patch1 -p0
%patch2 -p1

%build
%configure --with-systemdsystemunitdir=%_unitdir

%install
%make_install
install -d -m 0755  %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcnetlabel

%pre tools
%service_add_pre netlabel.service

%post tools
%service_add_post netlabel.service

%preun tools
%service_del_preun netlabel.service

%postun tools
%service_del_postun netlabel.service

%files tools
%defattr(-,root,root)
%doc LICENSE README CHANGELOG
%config(noreplace) %attr(600,root,root) %{_sysconfdir}/netlabel.rules
%{_sbindir}/netlabelctl
%{_sbindir}/netlabel-config
%{_sbindir}/rcnetlabel
%{_unitdir}/netlabel.service
%{_mandir}/man8/netlabelctl.8.gz
%{_mandir}/man8/netlabel-config.8.gz

%changelog
* Fri Oct 15 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_netlabel.service.patch
* Fri Dec  2 2016 mt@suse.com
- Fixed to build on factory and leap-42.2
  * Removed obsolete --enable-systemd configure option.
  * Pass explicit --with-systemdsystemunitdir configure option;
    it is used in the rpm file list anyway and avoids detection
    in configure using systemd.pc pkg-config query.
  * Removed unneeded systemd-devel build-require, which does not
    provide the systemd.pc pkg-config file, but libsystemd files.
  * Added systemd-rpm-macros build-require for reliable _unitdir.
- Fixed to call service script macros in the correct package.
* Tue Dec  1 2015 p.drouand@gmail.com
- Update to version 0.21
  * Converted the build system to autotools
  * Fixed a number of style/formatting problems, see 'make check-syntax'
  * Fixed a problem with parsing invalid network addresses
  * Fixed a problem with large numbers of MLS level/category translations
  * Fixed a number of problems identified by Coverity
  * Updated to the libnl3 API
  * Added a SUBMITTING_PATCHES file with instructions on how to contribute
  * Fixed some output formatting problems when listing the outbound mappings
  * Created a basic regression test framework and populated it with some
    basic tests, see the "tests/" directory
- Remove 0001-Port-to-libnl3.patch and netlabel_tools-0.20.diff; fixed
  on upstream release
- Update project and download Urls
- Unconditionally build with systemd support; the package doesn't
  build for SLE11 anyway
- Add systemd-devel dependency; checked by the configure script
* Thu Mar  5 2015 p.drouand@gmail.com
- Remove dependency on fillup and insserv; the packages provides neither
  sysconfig script nor sysvinit script
- Remove depreciated AUTHORS section
* Mon Jun  2 2014 crrodriguez@opensuse.org
- Port to libnl3 (0001-Port-to-libnl3.patch)
  This is the last package depending on libnl1, after all
  relevant requests are accepted, libnl1 can be dropped.
* Wed Mar 26 2014 mt@suse.de
- Install LICENSE, README, CHANGELOG as documentation
* Wed Mar 26 2014 mt@suse.de
- Update to netlabel tools 0.20 providing the following fixes:
  - Patch from Marius Tomaschewski <mt@suse.de> to fix the
    Makefile install target to allow installation by normal users
  - Fixed build problems on Debian/Ubuntu
  - Correctly read all the parts of multipart Netlink messages,
    fixed problems when trying to display large configurations
  - Updated the doxygen configuration file to work with modern
    doxygen versions
  - Updated and improved portions of the build mechanism
  - Incorporate fixes from the Fedora/RHEL RPMs
  - Add support for systemd with the inclusion of a systemd unit
    file, configuration file, and configuration helper script
- Fixed install rules to allow installation as normal users (again),
  corrected link option order for as-needed, adjusted service file,
  replacing netlabel_tools-0.19.diff by netlabel_tools-0.20.diff
  and adding netlabel_tools-0.20-service.diff patches.
- Removed unneeded netlabel_tools-0.19-version_info.diff patch
* Sat Feb 23 2013 andreas.stieger@gmx.de
- fix Makefile to find version_info file in openSUSE 12.3 and up,
  adding netlabel_tools-0.19-version_info.diff
* Wed May 16 2012 andreas.stieger@gmx.de
- Explicitly require libnl-1_1-devel for openSUSE 12.1 and up
  to fix build
* Wed Sep 30 2009 mt@suse.de
- Initial netlabel-tools package (fate#307618)
